==> libreoffice-still-sdk-24.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.js <==
var servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape =
[
    [ "FillProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#affe824eb78c13277161834e7fdff6cc9", null ],
    [ "LineProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#af8b545496add92e39f9d5d78886ab77b", null ],
    [ "RotationDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#ae9fedfa00d62d50167d9d93e11f071cb", null ],
    [ "ShadowProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a539272a082c3f6cf1df73da920b269e4", null ],
    [ "Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a337a0b131cd17ef2c08b51d5b37e04ef", null ],
    [ "Text", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a2ab1b80cf6ea8e2e918ab5e82713ebdd", null ],
    [ "CaptionAngle", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a5c1e71620fc9a3f0e4283fbf510c1910", null ],
    [ "CaptionEscapeAbsolute", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a7161590205aeecb5c28861038ecf54a0", null ],
    [ "CaptionEscapeDirection", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a5682562d58c04df3efff5cfd6f35f2a0", null ],
    [ "CaptionEscapeRelative", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a93a9b290ce896e58bd38201f77904cc7", null ],
    [ "CaptionGap", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a67402bfa7b85e28cf34fa25f32425853", null ],
    [ "CaptionIsEscapeRelative", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a0b809afccf751fa1525d37afe8ef00bd", null ],
    [ "CaptionIsFitLineLength", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a245aa53873a2c7533e2e188c1868898c", null ],
    [ "CaptionIsFixedAngle", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#ad8dc4bb2177620f9fe8f3abc5c1378a5", null ],
    [ "CaptionLineLength", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a7e3bb6a4eff601d3cee775634efef315", null ],
    [ "CaptionPoint", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a4001d1820dfe31609ac61e4684db282a", null ],
    [ "CaptionType", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a12a5b7f30312e23549790bab1aeeee0e", null ],
    [ "CornerRadius", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a996a59eb7a4cf0ae4e06d29ac82cc740", null ]
];

==> libreoffice-still-sdk-25.2.7-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.js <==
var servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape =
[
    [ "com::sun::star::drawing::FillProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#affe824eb78c13277161834e7fdff6cc9", null ],
    [ "com::sun::star::drawing::LineProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#af8b545496add92e39f9d5d78886ab77b", null ],
    [ "com::sun::star::drawing::RotationDescriptor", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#ae9fedfa00d62d50167d9d93e11f071cb", null ],
    [ "com::sun::star::drawing::ShadowProperties", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a539272a082c3f6cf1df73da920b269e4", null ],
    [ "com::sun::star::drawing::Shape", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a337a0b131cd17ef2c08b51d5b37e04ef", null ],
    [ "com::sun::star::drawing::Text", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a2ab1b80cf6ea8e2e918ab5e82713ebdd", null ],
    [ "CaptionAngle", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a5c1e71620fc9a3f0e4283fbf510c1910", null ],
    [ "CaptionEscapeAbsolute", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a7161590205aeecb5c28861038ecf54a0", null ],
    [ "CaptionEscapeDirection", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a5682562d58c04df3efff5cfd6f35f2a0", null ],
    [ "CaptionEscapeRelative", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a93a9b290ce896e58bd38201f77904cc7", null ],
    [ "CaptionGap", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a67402bfa7b85e28cf34fa25f32425853", null ],
    [ "CaptionIsEscapeRelative", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a0b809afccf751fa1525d37afe8ef00bd", null ],
    [ "CaptionIsFitLineLength", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a245aa53873a2c7533e2e188c1868898c", null ],
    [ "CaptionIsFixedAngle", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#ad8dc4bb2177620f9fe8f3abc5c1378a5", null ],
    [ "CaptionLineLength", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a7e3bb6a4eff601d3cee775634efef315", null ],
    [ "CaptionPoint", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a4001d1820dfe31609ac61e4684db282a", null ],
    [ "CaptionType", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a12a5b7f30312e23549790bab1aeeee0e", null ],
    [ "CornerRadius", "servicecom_1_1sun_1_1star_1_1drawing_1_1CaptionShape.html#a996a59eb7a4cf0ae4e06d29ac82cc740", null ]
];
